<?php
namespace Concrete\Package\EditorPermissions;

use Concrete\Core\Database\EntityManager\Provider\ProviderInterface;
use Concrete\Core\Database\EntityManager\Provider\StandardPackageProvider;
use Concrete\Core\Database\EntityManager\Provider\ProviderAggregateInterface;
use Concrete\Package\EditorPermissions\Handler\EditorPermissions as EditorPermissionsHandler;
use Concrete\Core\Routing\RouterInterface;
use Concrete\Core\Support\Facade\Events;
use Concrete\Core\Package\Package;
use Concrete\Core\Http\Request;
use Concrete\Core\Page\Page;

class Controller extends Package implements ProviderAggregateInterface
{
    protected $pkgHandle = 'editor_permissions';
    protected $appVersionRequired = '8.1.0';
    protected $pkgVersion = '1.0.0';

    protected $pkgAutoloaderRegistries = [
        'src' => 'Concrete\Package\EditorPermissions',
    ];

    public function getPackageDescription()
    {
        return t('Editor Permissions');
    }

    public function getPackageName()
    {
        return t('Editor Permissions');
    }

    public function install()
    {
        $pkg = parent::install();
        $page = Page::getByPath('/dashboard/system/basics/advanced_editor');
        if (0 == $page->getCollectionID()) {
            $sp = \SinglePage::add('/dashboard/system/basics/advanced_editor', $pkg);
            $sp->update(['cName' => t('Advanced Editor Permissions')]);
        }
    }

    public function uninstall()
    {
        parent::uninstall();
        $db = \Database::connection();
        if ($db->tableExists('EditorPermissions')) {
            $db->executeQuery('DROP TABLE `EditorPermissions`');
        }
    }

    public function on_start()
    {
        $this->registerRoutes();
        $app = $this->app;
        Events::addListener('on_before_dispatch', function ($event) use ($app) {
            /* @var Request $r */
            $r = $app->make(Request::class);
            if (!$r->matches('*/dashboard/system/basics/advanced_editor*')
                && !$r->matches('*/dashboard/system/basics/editor*')) {
                EditorPermissionsHandler::setupCurrentUserPlugins();
            }
        });
    }

    private function registerRoutes()
    {
        /* @var \Concrete\Core\Routing\RouterInterface $router */
        $router = $this->app->make(RouterInterface::class);
        $router->registerMultiple([
            '/ccm/editor_permissions/dialogs/add/{key}' => [Controller\Dialog\Add::class . '::view'],
            '/ccm/editor_permissions/dialogs/add/{key}/add' => [Controller\Dialog\Add::class . '::add'],
        ]);

        return $this;
    }

    /**
     * @return ProviderInterface
     */
    public function getEntityManagerProvider()
    {
        return new StandardPackageProvider($this->app, $this, [
            'src/Entity' => 'Concrete\Package\EditorPermissions\Entity',
        ]);
    }
}
