<?php
namespace Concrete\Package\EditorPermissions\Controller\Dialog;

use Concrete\Controller\Backend\UserInterface as BackendInterfaceController;
use Concrete\Package\EditorPermissions\Entity\Service\EditorPermission as EditorPermissionService;
use Concrete\Package\EditorPermissions\Plugin\PermissionsAssigner as PluginPermissions;
use Concrete\Package\EditorPermissions\Html\PermissionGroup as PermissionGroupHtml;
use Concrete\Core\Application\EditResponse;
use Concrete\Core\User\Group\GroupList;
use Concrete\Core\User\Group\Group;
use Concrete\Core\Page\Page;
use Permissions;
use Exception;

class Add extends BackendInterfaceController
{
    protected $viewPath = '/dialogs/add';

    protected function canAccess()
    {
        $p = new Permissions(Page::getByPath('/dashboard/system/basics/advanced_editor'));

        return $p->canViewPage();
    }

    public function view($key = '')
    {
        /* @var EditorPermissionService $service */
        $service = $this->app->make(EditorPermissionService::class);

        $groupList = new GroupList();
        $this->set('key', $key);
        $this->set('form', $this->app->make('helper/form'));
        $this->set('groupList', $groupList->getResults());
        $this->set('checkedList', $service->getPluginUserGroups($key));
        $this->set('token', $this->app->make('token'));
    }

    public function add()
    {
        $token = $this->app->make('token');

        if (!$token->validate('add')) {
            throw new Exception($token->getErrorMessage());
        }

        $plugin = $this->request->post('plugin');
        $groupIDs = $this->request->post('groups', []);

        $groups = [];
        foreach ($groupIDs as $gID) {
            $groups[] = Group::getByID(intval($gID));
        }

        /* @var PluginPermissions $permission */
        $permission = $this->app->make(PluginPermissions::class, [$plugin]);
        $permission->assignGroups($groups);

        $result = PermissionGroupHtml::getGroupsHtml($groups);

        $er = new EditResponse();
        $er->setMessage(t('Permissions updated successfully.'));
        $er->setAdditionalDataAttribute('result', $result);
        $er->outputJSON();
    }
}
