<?php
namespace Concrete\Package\EditorPermissions\Entity\Service;

use Concrete\Core\Application\Application;
use Concrete\Package\EditorPermissions\Entity\EntityBase;
use Concrete\Package\EditorPermissions\App;

abstract class AbstractServiceImpl implements ServiceInterface
{
    /**
     * @var Application
     */
    protected $app;

    public function __construct(Application $app)
    {
        $this->app = $app;
    }

    /**
     * Get full entity class name.
     *
     * @return string
     */
    abstract protected function getEntityClass();

    /**
     * {@inheritdoc}
     */
    public function repo()
    {
        return App::em()->getRepository($this->getEntityClass());
    }

    /**
     * {@inheritdoc}
     */
    public function newEntity()
    {
        return $this->app->make($this->getEntityClass());
    }

    /**
     * {@inheritdoc}
     */
    public function getList()
    {
        return $this->repo()->findAll();
    }

    /**
     * {@inheritdoc}
     */
    public function getByID($id)
    {
        return $this->repo()->find($id);
    }

    /**
     * {@inheritdoc}
     */
    public function saveData(EntityBase $entity, array $data)
    {
        $entity->setPropertiesFromArray($data);
        $entity->save();

        return true;
    }

    /**
     * {@inheritdoc}
     */
    public function delete(EntityBase $entity)
    {
        $entity->delete();

        return true;
    }

    /**
     * @param array $entities
     */
    public function bulkDelete($entities)
    {
        if (empty($entities)) {
            return;
        }

        $em = App::em(true);
        foreach ($entities as $entity) {
            $em->remove($entity);
        }

        $em->flush();
    }
}
