<?php
namespace Concrete\Package\EditorPermissions\Entity\Service;

use Concrete\Core\User\Group\Group;
use Concrete\Package\EditorPermissions\Entity\EditorPermission as EditorPermissionEntity;
use Concrete\Package\EditorPermissions\App;

class EditorPermission extends AbstractServiceImpl
{
    public function getEntityClass()
    {
        return EditorPermissionEntity::class;
    }

    /**
     * @param $plugin
     *
     * @return Group[]
     */
    public function getPluginUserGroups($plugin)
    {
        /* @var EditorPermission $editorPermission */
        $editorPermissions = $this->repo()->findBy(['plugin' => $plugin]);

        $groups = [];
        foreach ($editorPermissions as $editorPermission) {
            $g = $editorPermission->getUserGroup();
            $groups[$g->getGroupID()] = $g;
        }

        return $groups;
    }

    /**
     * @param $plugin
     *
     * @return EditorPermissionEntity[]
     */
    public function findByPlugin($plugin)
    {
        return $this->repo()->findBy(['plugin' => $plugin]);
    }

    /**
     * @param \User $u
     *
     * @return EditorPermissionEntity[]
     */
    public function findByUser($u)
    {
        $groupIDs = $u->getUserGroups();
        if ($u->isSuperUser() && !in_array(ADMIN_GROUP_ID, $groupIDs)) {
            $groupIDs[] = ADMIN_GROUP_ID;
        }

        return $this->repo()->findBy(['userGroupID' => $groupIDs]);
    }

    public function bulkInsert($plugin, array $groups)
    {
        if (empty($groups)) {
            return;
        }

        $em = App::em(true);
        foreach ($groups as $group) {
            $ep = $this->newEntity();
            $ep->setPlugin($plugin);
            $ep->setUserGroup($group);
            $em->persist($ep);
        }

        $em->flush();
    }
}
